pygeodesy.hausdorff.Hausdorff6Tuple

Package pygeodesy :: Module hausdorff :: Class Hausdorff6Tuple |
[frames] | no frames]

# Class Hausdorff6Tuple

       object --+
                |
            tuple --+
                    |
       object --+   |
                |   |
     named._Named --+
                    |
    named._NamedTuple --+
                        |
                       Hausdorff6Tuple

6-Tuple `(hd, i, j, mn, md, units)` with the Hausdorff distance `hd`, indices `i` and `j`, the total count `mn`, the `mean Hausdorff` distance `md` and the class or name of both distance `units`.

For `directed Hausdorff` distances, count `mn` is the number of model points considered. For `symmetric Hausdorff` distances count `mn` twice that.

Indices `i` and `j` are the `model` respectively `target` point with the `hd` distance.

Mean distance `md` is `None` if an `early break` occurred and early breaking was enabled by keyword argument `early=True`.

Instance Methods
toUnits(self, **Error_name) Overloaded `_NamedTuple.toUnits` for `hd` and `md` units. |
Inherited from `named._NamedTuple`: `__delattr__`, `__getattr__`, `__hash__`, `__repr__`, `__setattr__`, `__str__`, `dup`, `items`, `iteritems`, `iterunits`, `reUnit`, `toRepr`, `toStr`, `units` Inherited from `tuple`: `__add__`, `__contains__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__rmul__`, `count`, `index` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__init__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `named._NamedTuple`: `__new__`

Properties
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### toUnits (self, **Error_name) |
Overloaded `_NamedTuple.toUnits` for `hd` and `md` units. Arguments: `Error` - Error to raise for units issues (`UnitError`). `name` - Optional `name=NN` (`str`). Returns: A duplicate of this `Named-Tuple` (``Named-Tuple``). Raises: `Error` - Invalid `Named-Tuple` item or units class. Overrides: named._NamedTuple.toUnits